<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de" sourcelanguage="en">
<context>
    <name>OptionsWidget</name>
    <message>
        <location filename="../../OptionsWidget.ui" line="17"/>
        <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
        <translation>Im Normalfall ist für 32 oder 64-Bit-Beriebsysteme nur die jeweilige DLL wichtig. Möglicherweise muss die Windows UAC bestätigt werden, um die DLL zu laden.</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="20"/>
        <source>All the dlls are importants</source>
        <translatorcomment>fix english</translatorcomment>
        <translation>Alle DLLs sind wichtig (32Bit + 64Bit)</translation>
    </message>
    <message>
        <location filename="../../OptionsWidget.ui" line="34"/>
        <source>Register for all users</source>
        <translation>Für alle Benutzer registrieren</translation>
    </message>
</context>
</TS>
